Skip to contents

Fetches all the project-year combinations you can possibly set using the form fields at CZVV site https://vysledky.cermat.cz/statistika/. Useful if you plan to mine only a subset of the data in mine_links().

Usage

get_exam_events(force = FALSE, base_url = default_base_url())

Arguments

force

Force a refresh of the data, even if cached. Defaults to FALSE.

base_url

Base URL of the CERMAT website. Defaults to https://vysledky.cermat.cz/statistika/. Can be set session-wide with options(cermine.base_url = <your_url>).

Value

A tibble with the project and year options returned by the server.

Examples

if (FALSE) { # \dontrun{
get_exam_events()
} # }